============================
emaillib
============================

A simple library to ease the sending of emails with utf8 and attachments.


* Documentation: http://emaillib.readthedocs.io/en/latest

Features
--------

* Handles subject and message body as utf-8 by default
* Handles html and plain text
* Handles attachments either as list or comma delimited value arguments
* Supports CC and BCC
* Simply validates the provided recipient addresses
